///////////////////////////////////////////////////////////////////////////////
//
// Copyright (C) OMG Plc 2008.
// All rights reserved.  This software is protected by copyright
// law and international treaties.  No part of this software / document
// may be reproduced or distributed in any form or by any means,
// whether transiently or incidentally to some other use of this software,
// without the written permission of the copyright owner.
//
///////////////////////////////////////////////////////////////////////////////
//
// Real Time Client Stream API Header file.
// Version 1.0.0 BETA 4
// 
///////////////////////////////////////////////////////////////////////////////
// Exported DLL functions listed below:
///////////////////////////////////////////////////////////////////////////////

// Connects to the Real Time stream. Hostname string either IP address or "localhost" if running on same machine.
extern "C" __declspec(dllexport) bool Connect(const char* i_pHostname);

// Disconnects from the  Real Time stream. It is imperative that this function is called before the DLL is unloaded.
extern "C" __declspec(dllexport) bool Disconnect();

// States whether connected to the  Real Time stream. 
extern "C" __declspec(dllexport) bool IsConnected();

// Puts the system into pre-fetch mode for lower latency
extern "C" __declspec(dllexport) void SetPreFetchMode(bool i_bPreFetch);

// Transforms data into a left-handed co-ordinate system
extern "C" __declspec(dllexport) void SetLeftHandRule();

// Delivers data according to a right-handed co-ordinate system
extern "C" __declspec(dllexport) void SetRightHandRule();

// Transforms data into a co-ordinate system with a vertical Y-axis
extern "C" __declspec(dllexport) void SetYUp();

// Delivers data according to a co-ordinate system with a vertical Y-axis
extern "C" __declspec(dllexport) void SetZUp();

// Requests the next available frame from the Real Time stream. Returns true if successful.
extern "C" __declspec(dllexport) bool GetFrame();

// Returns the number of the last frame requested from the Real Time stream.
extern "C" __declspec(dllexport) bool GetFrameNumber(long& o_rNumber);

// Enables segment data in the stream.
extern "C" __declspec(dllexport) bool EnableSegmentData();

// Enables labelled reconstruction data (markers) in the stream.
extern "C" __declspec(dllexport) bool EnableMarkerData();

// Enables forceplate data (forces, moments and analog) in the stream.
extern "C" __declspec(dllexport) bool EnableForcePlateData();

// Returns the number of subjects in the Real Time stream.
extern "C" __declspec(dllexport) bool GetSubjectCount(unsigned int& o_rCount);   

// Returns the name of a particular subject. Expects input argument to be one-indexed.
extern "C" __declspec(dllexport) const char* GetSubjectName(unsigned int i_OneIndexedSubjectIndex);

// Returns the number of segments constituting the named subject.
extern "C" __declspec(dllexport) bool GetSegmentCount(const char* i_pSubjectName, unsigned int& o_rCount); 

// Returns the name of a particular segment of a subject. Expects input argument to be one-indexed.
extern "C" __declspec(dllexport) const char* GetSegmentName(const char* i_pSubjectName, unsigned int i_OneIndexedSegmentIndex);

// Returns the number of markers on the named subject.
extern "C" __declspec(dllexport) bool GetMarkerCount(const char* i_pSubjectName, unsigned int& o_rCount); 

// Returns the name of a particular marker on a subject. Expects input argument to be one-indexed.
extern "C" __declspec(dllexport) const char* GetMarkerName(const char* i_pSubjectName, unsigned int i_OneIndexedMarkerIndex);

// Returns the translation of a particular segment of a subject in global co-ordinates.
extern "C" __declspec(dllexport) bool GetGlobalSegmentTranslation(const char* i_pSubjectName, const char* i_pSegmentName, double o_pThreeVector[3], unsigned int& rbOccludedFlag);

// Returns the helical axis rotation of a particular segment of a subject in global co-ordinates. Helical representation.
extern "C" __declspec(dllexport) bool GetGlobalSegmentRotationHelical(const char* i_pSubjectName, const char* i_pSegmentName, double o_ThreeVector[3], unsigned int& o_rbOccludedFlag); 

// Returns the helical axis rotation of a particular segment of a subject in global co-ordinates. Quaternion representation.
extern "C" __declspec(dllexport) bool GetGlobalSegmentRotationQuaternion(const char* i_pSubjectName, const char* i_pSegmentName, double o_pFourVector[4], unsigned int& o_rbOccludedFlag); 

// Returns the translation of a particular marker on a subject in global co-ordinates.
extern "C" __declspec(dllexport) bool GetGlobalMarkerTranslation(const char* i_pSubjectName, const char* i_pMarkerName, double o_ThreeVector[3], unsigned int& o_rbOccludedFlag); 

// Returns the number of forceplates.
extern "C" __declspec(dllexport) bool GetForcePlateCount(unsigned int& o_rForcePlateCount); 

// Retrieves the ID of a forceplate.
extern "C" __declspec(dllexport) bool GetForcePlateID(unsigned int i_OneIndexedPlateIndex, unsigned int& o_rPlateID);

// retrieves the force vector from a particular plate in the current frame
extern "C" __declspec(dllexport) bool GetForceVector(unsigned int i_PlateID, double o_pForceVector[3]);  

// retrieves the moment vector from a particular plate in the current frame
extern "C" __declspec(dllexport) bool GetMomentVector(unsigned int i_PlateID, double o_pForceVector[3]); 

// retrieves the centre of pressure vector from a particular plate in the current frame
extern "C" __declspec(dllexport) bool GetCentreOfPressure(unsigned int i_PlateID, double o_pLocation[3]);

// Returns the number of analog inputs from a particular forceplate.
extern "C" __declspec(dllexport) bool GetNumberOfAnalogChannels(unsigned int i_PlateID, unsigned int& o_rChannelCount);

// Returns the raw analog value from a particular analog input for a particular forceplate.
extern "C" __declspec(dllexport) bool GetAnalogChannelVoltage(unsigned int i_PlateID, unsigned int i_OneIndexedChannelIndex, double& o_rVoltage);

///////////////////////////////////////////////////////////////////////////////
// End of function list.
///////////////////////////////////////////////////////////////////////////////
